@@ -10,8 +10,8 @@ import numpy as np
 
 from . import coriolis_parameter
 from .tools import first_derivative, get_layer_heights, gradient
+from .. import constants as mpconsts
 from ..cbook import is_string_like, iterable
-from ..constants import Cp_d, g, Rd
 from ..package_tools import Exporter
 from ..units import atleast_2d, check_units, concatenate, units
 from ..xarray import preprocess_xarray
@@ -434,7 +434,7 @@ def geostrophic_wind(heights, f, dx, dy):
     if heights.dimensionality['[length]'] == 2.0:
         norm_factor = 1. / f
     else:
-        norm_factor = g / f
+        norm_factor = mpconsts.g / f
 
     dhdy = first_derivative(heights, delta=dy, axis=-2)
     dhdx = first_derivative(heights, delta=dx, axis=-1)
@@ -519,7 +519,7 @@ def montgomery_streamfunction(height, temperature):
     get_isentropic_pressure
 
     """
-    return (g * height) + (Cp_d * temperature)
+    return (mpconsts.g * height) + (mpconsts.Cp_d * temperature)
 
 
 @exporter.export
@@ -568,8 +568,8 @@ def storm_relative_helicity(u, v, heights, depth, bottom=0 * units.m,
     storm_relative_u = u - storm_u
     storm_relative_v = v - storm_v
 
-    int_layers = (storm_relative_u[1:] * storm_relative_v[:-1] -
-                  storm_relative_u[:-1] * storm_relative_v[1:])
+    int_layers = (storm_relative_u[1:] * storm_relative_v[:-1]
+                  - storm_relative_u[:-1] * storm_relative_v[1:])
 
     # Need to manually check for masked value because sum() on masked array with non-default
     # mask will return a masked value rather than 0. See numpy/numpy#11736
@@ -626,23 +626,24 @@ def absolute_vorticity(u, v, dx, dy, lats, dim_order='yx'):
 @preprocess_xarray
 @check_units('[temperature]', '[pressure]', '[speed]', '[speed]',
              '[length]', '[length]', '[dimensionless]')
-def potential_vorticity_baroclinic(potential_temperature, pressure, u, v, dx, dy, lats,
-                                   axis=0, dim_order='yx'):
+def potential_vorticity_baroclinic(potential_temperature, pressure, u, v, dx, dy, lats):
     r"""Calculate the baroclinic potential vorticity.
 
-    .. math:: PV = -g \frac{\partial \theta}{\partial z}(\zeta + f)
+    .. math:: PV = -g \left(\frac{\partial u}{\partial p}\frac{\partial \theta}{\partial y}
+              - \frac{\partial v}{\partial p}\frac{\partial \theta}{\partial x}
+              + \frac{\partial \theta}{\partial p}(\zeta + f) \right)
 
-    This formula is based on equation 7.31a [Hobbs2006]_.
+    This formula is based on equation 4.5.93 [Bluestein1993]_.
 
     Parameters
     ----------
-    potential_temperature : (M, N, P) ndarray
+    potential_temperature : (P, M, N) ndarray
         potential temperature
-    pressure : (M, N, P) ndarray
+    pressure : (P, M, N) ndarray
         vertical pressures
-    u : (M, N) ndarray
+    u : (P, M, N) ndarray
         x component of the wind
-    v : (M, N) ndarray
+    v : (P, M, N) ndarray
         y component of the wind
     dx : float or ndarray
         The grid spacing(s) in the x-direction. If an array, there should be one item less than
@@ -658,30 +659,48 @@ def potential_vorticity_baroclinic(potential_temperature, pressure, u, v, dx, dy
 
     Returns
     -------
-    (M, N) ndarray
+    (P, M, N) ndarray
         baroclinic potential vorticity
 
     Notes
     -----
-    The same formula is used for isobaric and isentropic PV analysis. Provide winds
-    for vorticity calculations on the desired isobaric or isentropic surface. Three layers
-    of pressure/potential temperature are required in order to calculate the vertical
-    derivative (one above and below the desired surface).
+    This function will only work with data that is in (P, Y, X) format. If your data
+    is in a different order you will need to re-order your data in order to get correct
+    results from this function.
+
+    The same function can be used for isobaric and isentropic PV analysis. Provide winds
+    for vorticity calculations on the desired isobaric or isentropic surface. At least three
+    layers of pressure/potential temperature are required in order to calculate the vertical
+    derivative (one above and below the desired surface). The first two terms will be zero if
+    isentropic level data is used due to the gradient of theta in both the x and y-directions
+    will be zero since you are on an isentropic surface.
+
+    This function expects pressure/isentropic level to increase with increasing array element
+    (e.g., from higher in the atmosphere to closer to the surface. If the pressure array is
+    one-dimensional p[:, None, None] can be used to make it appear multi-dimensional.)
 
     """
-    if np.shape(potential_temperature)[axis] != 3:
-        raise ValueError('Length of potential temperature along axis '
-                         '{} must be 3.'.format(axis))
-    if np.shape(pressure)[axis] != 3:
-        raise ValueError('Length of pressure along axis '
-                         '{} must be 3.'.format(axis))
-    avor = absolute_vorticity(u, v, dx, dy, lats, dim_order=dim_order)
-    stability = first_derivative(potential_temperature, x=pressure, axis=axis)
-    # Get the middle layer stability derivative (index 1)
-    slices = [slice(None)] * stability.ndim
-    slices[axis] = 1
-    return (-1 * avor * g * stability[slices]).to(units.kelvin * units.meter**2 /
-                                                  (units.second * units.kilogram))
+    if ((np.shape(potential_temperature)[-3] < 3) or (np.shape(pressure)[-3] < 3)
+       or (np.shape(potential_temperature)[-3] != (np.shape(pressure)[-3]))):
+        raise ValueError('Length of potential temperature along the pressure axis '
+                         '{} must be at least 3.'.format(-3))
+
+    avor = absolute_vorticity(u, v, dx, dy, lats, dim_order='yx')
+    dthtadp = first_derivative(potential_temperature, x=pressure, axis=-3)
+
+    if ((np.shape(potential_temperature)[-2] == 1)
+       and (np.shape(potential_temperature)[-1] == 1)):
+        dthtady = 0 * units.K / units.m  # axis=-2 only has one dimension
+        dthtadx = 0 * units.K / units.m  # axis=-1 only has one dimension
+    else:
+        dthtady = first_derivative(potential_temperature, delta=dy, axis=-2)
+        dthtadx = first_derivative(potential_temperature, delta=dx, axis=-1)
+    dudp = first_derivative(u, x=pressure, axis=-3)
+    dvdp = first_derivative(v, x=pressure, axis=-3)
+
+    return (-mpconsts.g * (dudp * dthtady - dvdp * dthtadx
+                           + avor * dthtadp)).to(units.kelvin * units.meter**2
+                                                 / (units.second * units.kilogram))
 
 
 @exporter.export
@@ -851,7 +870,7 @@ def q_vector(u, v, temperature, pressure, dx, dy, static_stability=1):
     dvdy, dvdx = gradient(v, deltas=(dy, dx), axes=(-2, -1))
     dtempdy, dtempdx = gradient(temperature, deltas=(dy, dx), axes=(-2, -1))
 
-    q1 = -Rd / (pressure * static_stability) * (dudx * dtempdx + dvdx * dtempdy)
-    q2 = -Rd / (pressure * static_stability) * (dudy * dtempdx + dvdy * dtempdy)
+    q1 = -mpconsts.Rd / (pressure * static_stability) * (dudx * dtempdx + dvdx * dtempdy)
+    q2 = -mpconsts.Rd / (pressure * static_stability) * (dudy * dtempdx + dvdy * dtempdy)
 
     return q1.to_base_units(), q2.to_base_units()
