@@ -48,21 +48,18 @@ class SkewXTick(maxis.XTick):
         return self.get_loc() is None
 
     def _need_lower(self):
-        return (self._has_default_loc() or
-                transforms.interval_contains(self.axes.lower_xlim,
-                                             self.get_loc()))
+        return (self._has_default_loc()
+                or transforms.interval_contains(self.axes.lower_xlim, self.get_loc()))
 
     def _need_upper(self):
-        return (self._has_default_loc() or
-                transforms.interval_contains(self.axes.upper_xlim,
-                                             self.get_loc()))
+        return (self._has_default_loc()
+                or transforms.interval_contains(self.axes.upper_xlim, self.get_loc()))
 
     @property
     def gridOn(self):  # noqa: N802
         """Control whether the gridline is drawn for this tick."""
-        return (self._gridOn and (self._has_default_loc() or
-                transforms.interval_contains(self.get_view_interval(),
-                                             self.get_loc())))
+        return (self._gridOn and (self._has_default_loc()
+                or transforms.interval_contains(self.get_view_interval(), self.get_loc())))
 
     @gridOn.setter
     def gridOn(self, value):  # noqa: N802
@@ -205,19 +202,19 @@ class SkewXAxes(Axes):
         # coordinates thus performing the transform around the proper origin
         # We keep the pre-transAxes transform around for other users, like the
         # spines for finding bounds
-        self.transDataToAxes = (self.transScale +
-                                (self.transLimits +
-                                 transforms.Affine2D().skew_deg(self.rot, 0)))
+        self.transDataToAxes = (self.transScale
+                                + (self.transLimits
+                                   + transforms.Affine2D().skew_deg(self.rot, 0)))
 
         # Create the full transform from Data to Pixels
         self.transData = self.transDataToAxes + self.transAxes
 
         # Blended transforms like this need to have the skewing applied using
         # both axes, in axes coords like before.
-        self._xaxis_transform = (transforms.blended_transform_factory(
-            self.transScale + self.transLimits,
-            transforms.IdentityTransform()) +
-            transforms.Affine2D().skew_deg(self.rot, 0)) + self.transAxes
+        self._xaxis_transform = (
+            transforms.blended_transform_factory(self.transScale + self.transLimits,
+                                                 transforms.IdentityTransform())
+            + transforms.Affine2D().skew_deg(self.rot, 0)) + self.transAxes
 
     @property
     def lower_xlim(self):
@@ -252,7 +249,7 @@ class SkewT(object):
 
     """
 
-    def __init__(self, fig=None, rotation=30, subplot=(1, 1, 1)):
+    def __init__(self, fig=None, rotation=30, subplot=None, rect=None):
         r"""Create SkewT - logP plots.
 
         Parameters
@@ -270,6 +267,9 @@ class SkewT(object):
             :meth:`matplotlib.figure.Figure.add_subplot`. The
             :class:`matplotlib.gridspec.SubplotSpec`
             can be created by using :class:`matplotlib.gridspec.GridSpec`.
+        rect : tuple[float, float, float, float], optional
+            Rectangle (left, bottom, width, height) in which to place the axes. This
+            allows the user to place the axes at an arbitrary point on the figure.
 
         """
         if fig is None:
@@ -278,12 +278,23 @@ class SkewT(object):
             fig = plt.figure(figsize=figsize)
         self._fig = fig
 
-        # Handle being passed a tuple for the subplot, or a GridSpec instance
-        try:
-            len(subplot)
-        except TypeError:
-            subplot = (subplot,)
-        self.ax = fig.add_subplot(*subplot, projection='skewx', rotation=rotation)
+        if rect and subplot:
+            raise ValueError("Specify only one of `rect' and `subplot', but not both")
+
+        elif rect:
+            self.ax = fig.add_axes(rect, projection='skewx', rotation=rotation)
+
+        else:
+            if subplot is not None:
+                # Handle being passed a tuple for the subplot, or a GridSpec instance
+                try:
+                    len(subplot)
+                except TypeError:
+                    subplot = (subplot,)
+            else:
+                subplot = (1, 1, 1)
+
+            self.ax = fig.add_subplot(*subplot, projection='skewx', rotation=rotation)
         self.ax.grid(True)
 
     def plot(self, p, t, *args, **kwargs):
@@ -445,7 +456,7 @@ class SkewT(object):
             p = np.linspace(*self.ax.get_ylim()) * units.mbar
 
         # Assemble into data for plotting
-        t = dry_lapse(p, t0[:, np.newaxis]).to(units.degC)
+        t = dry_lapse(p, t0[:, np.newaxis], 1000. * units.mbar).to(units.degC)
         linedata = [np.vstack((ti, p)).T for ti in t]
 
         # Add to plot
@@ -498,7 +509,7 @@ class SkewT(object):
             p = np.linspace(*self.ax.get_ylim()) * units.mbar
 
         # Assemble into data for plotting
-        t = moist_lapse(p, t0[:, np.newaxis]).to(units.degC)
+        t = moist_lapse(p, t0[:, np.newaxis], 1000. * units.mbar).to(units.degC)
         linedata = [np.vstack((ti, p)).T for ti in t]
 
         # Add to plot
@@ -864,8 +875,8 @@ class Hodograph(object):
                 # Find any bounds not in the data and interpolate them
                 interpolation_heights = [bound.m for bound in bounds if bound not in c]
                 interpolation_heights = np.array(interpolation_heights) * bounds.units
-                interpolation_heights = (np.sort(interpolation_heights) *
-                                         interpolation_heights.units)
+                interpolation_heights = (np.sort(interpolation_heights)
+                                         * interpolation_heights.units)
                 (interpolated_heights, interpolated_u,
                  interpolated_v) = interpolate_1d(interpolation_heights, c, c, u, v)
 
