@@ -5,11 +5,14 @@
 from __future__ import absolute_import
 
 import functools
+import logging
 import re
 import warnings
 
 import xarray as xr
 from xarray.core.accessors import DatetimeAccessor
+from xarray.core.indexing import expanded_indexer
+from xarray.core.utils import either_dict_or_kwargs, is_dict_like
 
 from .units import DimensionalityError, units
 
@@ -17,6 +20,8 @@ __all__ = []
 readable_to_cf_axes = {'time': 'T', 'vertical': 'Z', 'y': 'Y', 'x': 'X'}
 cf_to_readable_axes = {readable_to_cf_axes[key]: key for key in readable_to_cf_axes}
 
+log = logging.getLogger(__name__)
+
 
 @xr.register_dataarray_accessor('metpy')
 class MetPyAccessor(object):
@@ -67,7 +72,7 @@ class MetPyAccessor(object):
         """Return the coordinate variable corresponding to the given individual axis type."""
         if axis in readable_to_cf_axes:
             for coord_var in self._data_array.coords.values():
-                if coord_var.attrs.get('axis') == readable_to_cf_axes[axis]:
+                if coord_var.attrs.get('_metpy_axis') == readable_to_cf_axes[axis]:
                     return coord_var
             raise AttributeError(axis + ' attribute is not available.')
         else:
@@ -111,7 +116,8 @@ class MetPyAccessor(object):
     def as_timestamp(self):
         """Return the data as unix timestamp (for easier time derivatives)."""
         attrs = {key: self._data_array.attrs[key] for key in
-                 {'standard_name', 'long_name', 'axis'} & set(self._data_array.attrs)}
+                 {'standard_name', 'long_name', 'axis', '_metpy_axis'}
+                 & set(self._data_array.attrs)}
         attrs['units'] = 'seconds'
         return xr.DataArray(self._data_array.values.astype('datetime64[s]').astype('int'),
                             name=self._data_array.name,
@@ -140,6 +146,38 @@ class MetPyAccessor(object):
             raise ValueError('Given axis is not valid. Must be an axis number, a dimension '
                              'coordinate name, or a standard axis type.')
 
+    class _LocIndexer(object):
+        """Provide the unit-wrapped .loc indexer for data arrays."""
+
+        def __init__(self, data_array):
+            self.data_array = data_array
+
+        def expand(self, key):
+            """Parse key using xarray utils to ensure we have dimension names."""
+            if not is_dict_like(key):
+                labels = expanded_indexer(key, self.data_array.ndim)
+                key = dict(zip(self.data_array.dims, labels))
+            return key
+
+        def __getitem__(self, key):
+            key = _reassign_quantity_indexer(self.data_array, self.expand(key))
+            return self.data_array.loc[key]
+
+        def __setitem__(self, key, value):
+            key = _reassign_quantity_indexer(self.data_array, self.expand(key))
+            self.data_array.loc[key] = value
+
+    @property
+    def loc(self):
+        """Make the LocIndexer available as a property."""
+        return self._LocIndexer(self._data_array)
+
+    def sel(self, indexers=None, method=None, tolerance=None, drop=False, **indexers_kwargs):
+        """Wrap DataArray.sel to handle units."""
+        indexers = either_dict_or_kwargs(indexers, indexers_kwargs, 'sel')
+        indexers = _reassign_quantity_indexer(self._data_array, indexers)
+        return self._data_array.sel(indexers, method=method, tolerance=tolerance, drop=drop)
+
 
 @xr.register_dataset_accessor('metpy')
 class CFConventionHandler(object):
@@ -164,12 +202,11 @@ class CFConventionHandler(object):
             try:
                 proj_var = self._dataset.variables[proj_name]
             except KeyError:
-                warnings.warn(
+                log.warning(
                     'Could not find variable corresponding to the value of '
                     'grid_mapping: {}'.format(proj_name))
             else:
                 var.coords['crs'] = CFProjection(proj_var.attrs)
-                var.attrs.pop('grid_mapping')
 
         self._fixup_coords(var)
 
@@ -271,12 +308,12 @@ class CFConventionHandler(object):
             # Check for units, either by dimensionality or name
             if (axis in cls.criteria['units'] and (
                     (
-                        cls.criteria['units'][axis]['match'] == 'dimensionality' and
-                        (units.get_dimensionality(var.attrs.get('units')) ==
-                         units.get_dimensionality(cls.criteria['units'][axis]['units']))
+                        cls.criteria['units'][axis]['match'] == 'dimensionality'
+                        and (units.get_dimensionality(var.attrs.get('units'))
+                             == units.get_dimensionality(cls.criteria['units'][axis]['units']))
                     ) or (
-                        cls.criteria['units'][axis]['match'] == 'name' and
-                        var.attrs.get('units') in cls.criteria['units'][axis]['units']
+                        cls.criteria['units'][axis]['match'] == 'name'
+                        and var.attrs.get('units') in cls.criteria['units'][axis]['units']
                     ))):
                 return True
 
@@ -287,8 +324,8 @@ class CFConventionHandler(object):
     def _fixup_coords(self, var):
         """Clean up the units on the coordinate variables."""
         for coord_name, data_array in var.coords.items():
-            if (self.check_axis(data_array, 'x', 'y') and
-                    not self.check_axis(data_array, 'lon', 'lat')):
+            if (self.check_axis(data_array, 'x', 'y')
+                    and not self.check_axis(data_array, 'lon', 'lat')):
                 try:
                     var.coords[coord_name].metpy.convert_units('meters')
                 except DimensionalityError:  # Radians!
@@ -335,12 +372,9 @@ class CFConventionHandler(object):
     @staticmethod
     def _assign_axes(coord_map, var):
         """Assign axis attribute to coordinates in var according to coord_map."""
-        for coord_var in var.coords.values():
-            if 'axis' in coord_var.attrs:
-                del coord_var.attrs['axis']
         for axis in coord_map:
             if coord_map[axis] is not None:
-                coord_map[axis].attrs['axis'] = axis
+                coord_map[axis].attrs['_metpy_axis'] = axis
 
     def _resolve_axis_conflict(self, axis, coord_lists):
         """Handle axis conflicts if they arise."""
@@ -362,11 +396,32 @@ class CFConventionHandler(object):
             return
 
         # Ambiguous axis, raise warning and do not parse
-        warnings.warn('DataArray of requested variable has more than one ' +
-                      cf_to_readable_axes[axis] + ' coordinate. Specify the unique axes ' +
-                      'using the coordinates argument.')
+        warnings.warn('DataArray of requested variable has more than one '
+                      + cf_to_readable_axes[axis]
+                      + ' coordinate. Specify the unique axes using the coordinates argument.')
         coord_lists[axis] = []
 
+    class _LocIndexer(object):
+        """Provide the unit-wrapped .loc indexer for datasets."""
+
+        def __init__(self, dataset):
+            self.dataset = dataset
+
+        def __getitem__(self, key):
+            parsed_key = _reassign_quantity_indexer(self.dataset, key)
+            return self.dataset.loc[parsed_key]
+
+    @property
+    def loc(self):
+        """Make the LocIndexer available as a property."""
+        return self._LocIndexer(self._dataset)
+
+    def sel(self, indexers=None, method=None, tolerance=None, drop=False, **indexers_kwargs):
+        """Wrap Dataset.sel to handle units."""
+        indexers = either_dict_or_kwargs(indexers, indexers_kwargs, 'sel')
+        indexers = _reassign_quantity_indexer(self._dataset, indexers)
+        return self._dataset.sel(indexers, method=method, tolerance=tolerance, drop=drop)
+
 
 def preprocess_xarray(func):
     """Decorate a function to convert all DataArray arguments to pint.Quantities.
@@ -386,8 +441,8 @@ def check_matching_coordinates(func):
     """Decorate a function to make sure all given DataArrays have matching coordinates."""
     @functools.wraps(func)
     def wrapper(*args, **kwargs):
-        data_arrays = ([a for a in args if isinstance(a, xr.DataArray)] +
-                       [a for a in kwargs.values() if isinstance(a, xr.DataArray)])
+        data_arrays = ([a for a in args if isinstance(a, xr.DataArray)]
+                       + [a for a in kwargs.values() if isinstance(a, xr.DataArray)])
         if len(data_arrays) > 1:
             first = data_arrays[0]
             for other in data_arrays[1:]:
@@ -408,3 +463,34 @@ if not hasattr(DatetimeAccessor, 'strftime'):
         return strs.values.reshape(values.shape)
 
     DatetimeAccessor.strftime = strftime
+
+
+def _reassign_quantity_indexer(data, indexers):
+    """Reassign a units.Quantity indexer to units of relevant coordinate."""
+    def _to_magnitude(val, unit):
+        try:
+            return val.to(unit).m
+        except AttributeError:
+            return val
+
+    for coord_name in indexers:
+        # Handle axis types for DataArrays
+        if (isinstance(data, xr.DataArray) and coord_name not in data.dims
+                and coord_name in readable_to_cf_axes):
+            axis = coord_name
+            coord_name = next(data.metpy.coordinates(axis)).name
+            indexers[coord_name] = indexers[axis]
+            del indexers[axis]
+
+        # Handle slices of quantities
+        if isinstance(indexers[coord_name], slice):
+            start = _to_magnitude(indexers[coord_name].start, data[coord_name].metpy.units)
+            stop = _to_magnitude(indexers[coord_name].stop, data[coord_name].metpy.units)
+            step = _to_magnitude(indexers[coord_name].step, data[coord_name].metpy.units)
+            indexers[coord_name] = slice(start, stop, step)
+
+        # Handle quantities
+        indexers[coord_name] = _to_magnitude(indexers[coord_name],
+                                             data[coord_name].metpy.units)
+
+    return indexers
